* Activity 3 answers.

* Open the act23data.sav file.

* Getting person mean stress (for later).
COMPUTE PMstress = MEAN(stress1 TO stress5).
VARIABLE LABELS PMstress "Person Mean Stress".
EXECUTE.

* Stacking data for MIXED.
VARSTOCASES
	/MAKE severity FROM severity1 TO severity5
	/MAKE stress FROM stress1 TO stress5
	/INDEX month (5)
	/KEEP = ALL
	/NULL = DROP.

* Labeling newly created stacked variables.
VARIABLE LABELS 	month  "Month of Study (1 to 5)"
			severity "Time-Varying Severity Outcome"
			stress "Time-Varying Stress Predictor".
EXECUTE.

* Centering time at first occasion.
COMPUTE month1 = month - 1.
COMPUTE month5 = month - 5.
VARIABLE LABELS 
    month1 "Month of Study (0=1)"
    month5 "Month of Study (0=5)".

* Add the rest of your centered variables here.
COMPUTE age40 = baseage - 40.
IF (treat=1) treat0=0.
IF (treat=2) treat0=1.
IF (treat=1) treat1=1.
IF (treat=2) treat1=0.
VARIABLE LABELS   
	  age40  "Age at Baseline (0=40)"
			treat0 "Treatment Group (0=no, 1=yes)"
			treat1 "Treatment Group (0=yes, 1=no)".

* Centering level-2 predictor of stress.
COMPUTE pmstress5 = pmstress - 5.
VARIABLE LABELS pmstress5 "Person Mean Stress (0=5)".

* GRAND-Mean-Centering level-1 predictor of stress.
COMPUTE tvstress5 = stress - 5.
VARIABLE LABELS tvstress5 "Time-Varying Stress (0=5)".

* PERSON-Mean-Centering level-1 predictor of stress.
COMPUTE wpstress = stress - pmstress.
VARIABLE LABELS wpstress "Within-Person Stress (0=PM)".

EXECUTE.


/* General form of MIXED:
MIXED dv BY categorical and nesting variables WITH continuous variables
	/METHOD  = REML (default) or ML
	/PRINT   = regression solution, covariance tests, G and R matrices
	/FIXED   = model predictors and interactions
	/RANDOM  = INTERCEPT random effects | SUBJECT(idvar) COVTYPE(unstructured)
	/REPEATED = categorical time | SUBJECT(idvar) COVTYPE(whatever structure).
*/


* Baseline unconditional model.
TITLE "Random Quadratic Unconditional Baseline Model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).

* 1: Effects of age:
	 Main effect of age --> effect on severity at month1=0
	 Age*month1 --> effect on linear slope for month
	 Age*month1*month1 --> effect on quadratic slope for month.

TITLE "Add 3 Effects of age".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV 
	/FIXED  = month1 month1*month1 
			        age40 age40*month1 age40*month1*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).

TITLE "Drop age by quadratic month".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
		         age40 age40*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).

TITLE "Drop age by linear month - final age model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).


* 2: Effects of group:
	 First estimate using control group as a reference.

TITLE "Control group full model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40 
           treat0 treat0*month1 treat0*month1*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).

TITLE "Drop control group by quadratic month".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40
           treat0 treat0*month1 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
* a: Control group did change significantly over time --> month1 effect
  b: (don't know yet)
  c: Treatment group decline more --> treat0*month1 effect
  d: No difference between groups in severity at month1=0 --> treat0 effect
  e: (don't know yet).

* Now re-estimating model using treatment as reference to get b.
TITLE "Previous model, new reference point for group".
MIXED severity BY PersonID month WITH month1 age40 treat1 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40 
           treat1 treat1*month1 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
* a: (from previous model)
  b: Treatment group did change significantly over time --> month1 effect
  c: (from previous model, just backwards)
  d: (from previous model)
  e: (don't know yet).

* Now re-estimating model using treatment and month=5 as reference to get e.
TITLE "Previous model, new reference point for month and group".
MIXED severity BY PersonID month WITH month5 age40 treat1 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month5 month5*month5 
           age40 
           treat1 treat1*month5 
 /RANDOM = INTERCEPT month5 month5*month5 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
* a: (from previous model)
  b: Treatment group still changed significantly over time --> month5 effect
  c: (from previous model, just backwards)
  d: (from previous model)
  e:  Treatment is significantly lower in severity at month5=0 --> treat1 effect.

* 3:ICC for Stress (=.70).
TITLE "Random Intercept Only Baseline Model (equal to Compound Symmetry)".
MIXED stress BY PersonID month  
	/METHOD = ML
	/PRINT = SOLUTION TESTCOV 
	/FIXED =  
	/RANDOM = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).

* 4: Effects of stress:
     First estimate using person-mean-centering for stress.
TITLE "PMC stress model".
MIXED severity BY PersonID month WITH month1 age40 treat0 pmstress5 wpstress
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV 
	/FIXED  = month1 month1*month1 age40 treat0 treat0*month1
		         pmstress5 wpstress 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID)
 /TEST = "Context Effectual"	pmstress5 1 wpstress -1.
* a: Greater person mean stress predicts greater mean severity --> pmstress5 effect
  b: More stress than usual sort of predicts more severity than usual --> wpstress effect
  c: (don't know yet, but could get via TEST statement as shown)

* Re-estimate model using grand-mean-centering for stress to get (c).
TITLE "GMC stress model".
MIXED severity BY PersonID month WITH month1 age40 treat0 pmstress5 tvstress5
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV  
	/FIXED  = month1 month1*month1 age40 treat0 treat0*month1
		         tvstress5 pmstress5 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
* c: Is additional impact of pmstress after controlling for current stress --> pmstress5 effect.


