
 * Open the act23data.dta file

 * Stacking data for XTMIXED (wide to long)
 * list time-varying variables first, i(level2ID) j(newtimeID)
 reshape long severity stress, i(PersonID) j(month)

 * Labeling newly created stacked variables
label variable month  "Month of Study (1 to 5)"
label variable severity "Time-Varying Severity Outcome"
label variable stress "Time-Varying Stress Predictor"

 * Centering time at first occasion
gen month1 = month - 1
gen month1sq = month1 * month1
label variable month1 "Linear Month of Study (0=1)"
label variable month1sq "Quadratic Month of Study (0=1)"

 * Getting person mean stress (for use in activity 3)
egen PMstress = mean(stress), by(PersonID)
label variable PMstress "Person Mean Stress"
 
 * You can add the rest of your centered variables for activity 3 here

 * Center month at 5 to test end-of-study effects of group
gen month5 = month - 5
label variable month5 "Linear Month of Study (0=5)"
gen month5sq = month5 * month5
label variable month5sq "Quadratic Month of Study (0=5)"

 * Center age at 40
gen age40 = baseage - 40
label variable age40 "Baseline Age (0=40)" 

 * Recode treatment group (two variables for each group as reference)
gen treat0 = treat
recode treat0 (1=0) (2=1)
label variable treat0 "Treatment Group (0=C, 1=T)"
gen treat1 = treat
recode treat1 (1=1) (2=0)
label variable treat1 "Treatment Group (1=C, 0=T)"

 * Center stress variables at each level
gen PMstress5 = PMstress - 5
label variable PMstress5 "Level-2 Person Mean Stress (0=5)" 
gen WPstress = stress - PMstress 
label variable WPstress "Level-1 Within-Person Stress (0=PM)"
gen TVstress5 = stress - 5 
label variable TVstress5 "Level-1 Time-Varying Stress (0=5)"

///////////////////////////////////////////////////////////////////////////////////////
// xtmixed DV fixed effects, FE options || Level2ID: random effects, RE options ///
//	  variance reml/mle covariance(Gmatrix type) residuals(Rmatrix type), t(Level1ID),
//	  estat ic n(#persons),
//    estimates store ModelName,  
// 	  lrtest BiggerModel SmallerModel
///////////////////////////////////////////////////////////////////////////////////////

 * STATA Random Quadratic Time Baseline Model
xtmixed severity c.month1 c.month1sq,  || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)

 /* 1: Effects of age:
	 Main effect of age --> effect on severity at month1=0
	 Age*month1 --> effect on linear slope for month
	 Age*month1*month1 --> effect on quadratic slope for month */
	
 * STATA Add 3 effects of age
xtmixed severity c.month1 c.month1sq c.age40 c.age40#c.month1 c.age40#c.month1#c.month1sq ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
	 
 * STATA Drop age by quadratic month
xtmixed severity c.month1 c.month1sq c.age40 c.age40#c.month1 ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
	
 * STATA Drop age by linear month - final age model
xtmixed severity c.month1 c.month1sq c.age40 ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
	

 * 2: Effects of group: First estimate using control group as a reference

 * STATA Control group full model
xtmixed severity c.month1 c.month1sq c.age40 ///
	c.treat0 c.treat0#c.month1 c.treat0#c.month1sq  ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)

 * STATA Drop control group by quadratic month
xtmixed severity c.month1 c.month1sq c.age40 ///
	c.treat0 c.treat0#c.month1   ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
 *  a: Control group did change significantly over time --> month1 effect
 *  b: (don't know yet)
 *  c: Treatment group decline more --> treat0*month1 effect
 *  d: No difference between groups in severity at month1=0 --> treat0 effect
 *  e: (don't know yet)

 * Now re-estimating model using treatment as reference to get b
 * STATA Previous model, new reference point for group
xtmixed severity c.month1 c.month1sq c.age40 ///
	c.treat1 c.treat1#c.month1   ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
 * a: (from previous model)
 * b: Treatment group did change significantly over time --> month1 effect
 * c: (from previous model, just backwards)
 * d: (from previous model)
 * e: (don't know yet)

 * Now re-estimating model using treatment and month=5 as reference to get e.
 * Previous model, new reference point for month and group
xtmixed severity c.month5 c.month5sq c.age40 ///
	c.treat1 c.treat1#c.month5   ///
    || PersonID: month5 month5sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
 * a: (from previous model)
 * b: Treatment group still changed significantly over time --> month5 effect
 * c: (from previous model, just backwards)
 * d: (from previous model)
 * e:  Treatment is significantly lower in severity at month5=0 --> treat1 effect
 
 * 3:ICC for Stress (=.70)
 * STATA Empty Means, Random Intercept Model for Stress
xtmixed stress,  || PersonID: ,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101)

 * 4: Effects of stress:
 * First estimate using person-mean-centering for stress
 * STATA PMC stress model	
xtmixed severity c.month1 c.month1sq c.age40 ///
	c.treat0 c.treat0#c.month1 c.PMstress5 c.WPstress  ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID),
	lincom 1*PMstress5 - 1*WPstress 	// Contextual Effect (Diff of BP and WP effects)
 * a: Greater person mean stress predicts greater mean severity --> PMstress5 effect
 * b: More stress than usual sort of predicts more severity than usual --> WPstress effect
 * c: (don't know yet, but could get via LINCOM statement, as shown)
	
 * Re-estimate model using grand-mean-centering for stress to get (c)
 * GMC stress model
 xtmixed severity c.month1 c.month1sq c.age40 ///
	c.treat0 c.treat0#c.month1 c.PMstress5 c.TVstress5  ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID)
 * c: Is additional impact of pmstress after controlling for current stress --> PMstress5 effect
