* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for original SAS files for these models;
%LET filepath = F:\12_ICPSR\ICPSR_2012_Download\SAS;
LIBNAME filepath "&filepath.";
	
* SAS code to read data into work library and center predictors;
DATA work.example6; SET filepath.example6;
* Level-2 effect of Negative Mood (mean=0, SD=1);
  PMnm0 = PMnegmood - 0;  LABEL PMnm0 = "PMnm0: Person Mean Negative Mood (0=0)";
* Level-1 effect to use with PERSON-MEAN-CENTERING;
  WPnm  = negmood  - PMnegmood; LABEL wpnm  = "WPnm: Within-Person Negative Mood (0=PM)";
* Level-1 effect to use with GRAND-MEAN-CENTERING;
  TVnm0 = negmood - 0; LABEL TVnm0  = "TVnm0: Time-Varying Negative Mood (0=0)";
RUN;

******************************************************************************
****** 						EXAMPLE 6 MODELS							******
******************************************************************************;

TITLE "SAS Model 1a: Empty Model for Daily Glucose Outcome";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / VCORR SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; RUN;

TITLE "SAS Model 1b: Empty Model for Daily Negative Mood Predictor";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL negmood = / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / VCORR SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; RUN;

TITLE "SAS Model 2a: Fixed Effects of Negative Mood using PMC";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = WPnm PMnm0 / SOLUTION DDFM=Satterthwaite OUTPM=MoodPred; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Within-Person Mood Effect" 	WPnm  1;
	ESTIMATE "Between-Person Mood Effect" 	PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1 WPnm -1;
RUN; PROC CORR NOSIMPLE DATA=MoodPred; VAR lglucAM pred; RUN;

TITLE "SAS Model 2b: Random Effect of WP Negative Mood using PMC";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = WPnm PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT WPnm / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Within-Person Mood Effect" 	WPnm  1;
	ESTIMATE "Between-Person Mood Effect" 	PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 	PMnm0 1 WPnm -1;  RUN; 

TITLE "SAS Model 2c: Fixed Effects of Sex (0=M, 1=F) by PMC Negative Mood";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = WPnm PMnm0 sexmf WPnm*sexmf PMnm0*sexmf / SOLUTION DDFM=Satterthwaite OUTPM=SexPred; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Intercept: Men (Mood=0)"		  		  intercept 1 sexmf 0;
	ESTIMATE "Intercept: Women (Mood=0)"	  		  intercept 1 sexmf 1;
	ESTIMATE "Intercept: Women Diff (Mood=0)" 		  sexmf 1;
	ESTIMATE "Within-Person Mood Effect: Men" 	  	  WPnm 1 WPnm*sexmf 0;
	ESTIMATE "Within-Person Mood Effect: Women" 	  WPnm 1 WPnm*sexmf 1;
	ESTIMATE "Within-Person Mood Effect: Women Diff"  WPnm*sexmf 1;
	ESTIMATE "Between-Person Mood Effect: Men" 	      PMnm0 1 PMnm0*sexmf 0;
	ESTIMATE "Between-Person Mood Effect: Women" 	  PMnm0 1 PMnm0*sexmf 1;
	ESTIMATE "Between-Person Mood Effect: Women Diff" PMnm0*sexmf 1;
	ESTIMATE "Contextual Mood Effect: Men" 			  PMnm0 1 PMnm0*sexMF 0 WPnm -1 WPnm*sexMF  0;
	ESTIMATE "Contextual Mood Effect: Women" 		  PMnm0 1 PMnm0*sexMF 1 WPnm -1 WPnm*sexMF -1;
	ESTIMATE "Contextual Mood Effect: Women Diff"     PMnm0*sexMF 1 WPnm*sexMF -1;
RUN; PROC CORR NOSIMPLE DATA=SexPred; VAR lglucAM pred; RUN;

TITLE "SAS Model 3: Fixed Effect of TV Negative Mood only using GMC";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; RUN; 

TITLE "SAS Model 3a: Fixed Effects of Negative Mood using GMC";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Within-Person Mood Effect" 	TVnm0 1;
	ESTIMATE "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1;  RUN;

TITLE "SAS Model 3b: Random Effect of TV Negative Mood using GMC";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT TVnm0 / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Within-Person Mood Effect" 	TVnm0 1;
	ESTIMATE "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1;  RUN; 

TITLE "SAS Model 3c: Fixed Effects of Sex (0=M, 1=F) by GMC Negative Mood";
PROC MIXED DATA=work.example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 PMnm0 sexmf TVnm0*sexmf PMnm0*sexmf / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ESTIMATE "Intercept: Men (Mood=0)"			intercept 1 sexmf 0;
	ESTIMATE "Intercept: Women (Mood=0)"		intercept 1 sexmf 1;
	ESTIMATE "Intercept: Women Diff (Mood=0)" 	sexmf 1;
	ESTIMATE "Within-Person Effect: Men" 	  	TVnm0 1 TVnm0*sexmf 0;
	ESTIMATE "Within-Person Effect: Women" 	  	TVnm0 1 TVnm0*sexmf 1;
	ESTIMATE "Within-Person Effect: Women Diff" TVnm0*sexmf 1;
	ESTIMATE "Between-Person Effect: Men" 	  	TVnm0 1 TVnm0*sexmf 0 PMnm0 1PMnm0*sexmf 0;
	ESTIMATE "Between-Person Effect: Women"     TVnm0 1 TVnm0*sexmf 1 PMnm0 1PMnm0*sexmf 1;
	ESTIMATE "Between-Person Effect: Women Diff" TVnm0*sexmf 1 PMnm0*sexmf 1;
	ESTIMATE "Contextual Effect: Men" 			PMnm0 1 PMnm0*sexmf 0;
	ESTIMATE "Contextual Effect: Women" 	  	PMnm0 1 PMnm0*sexmf 1;
	ESTIMATE "Contextual Effect: Women Diff" 	PMnm0*sexmf 1;  RUN; 
