* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for original SAS files for these models;
%LET filepath = F:\12_ICPSR\ICPSR_2012_Download\SAS;
LIBNAME filepath "&filepath.";
* SAS code to read data into work library;
DATA work.example8; SET filepath.example8; RUN;

* Getting means per primary school and secondary school of kid predictor;
PROC SORT DATA=work.example8; BY pschool; RUN;
PROC MEANS NOPRINT DATA=work.example8; BY pschool; VAR pupSES; 
	OUTPUT OUT=Pses MEAN(pupSES)=pmSES; RUN;
PROC SORT DATA=work.example8; BY sschool; RUN;
PROC MEANS NOPRINT DATA=work.example8; BY sschool; VAR pupSES; 
	OUTPUT OUT=Sses MEAN(pupSES)=smSES; RUN;

* Merge back into individual data;
PROC SORT DATA=work.example8; BY pschool; RUN;
DATA work.example8; MERGE work.example8 Pses; BY pschool; DROP _TYPE_ _FREQ_; 
	LABEL pmSES= "pmSES: Primary School Mean SES"; RUN;
PROC SORT DATA=work.example8; BY sschool; RUN;
DATA work.example8; MERGE work.example8 Sses; BY sschool; DROP _TYPE_ _FREQ_;
	LABEL smSES= "smSES: Secondary School Mean SES"; RUN;

* Descriptives for data;
PROC MEANS DATA=work.example8; VAR achiev pdenom sdenom pupSES pmSES smSES; RUN;
* Center and label predictors;
DATA work.example8; SET work.example8;
	pupSES4 = pupSES - 4; LABEL pupSES4= "pupSES4: Student SES (0=4)";
	pmSES4  = pmSES - 4;  LABEL pmSES4=  "pmSES4: Primary School Mean SES (0=4)";
	smSES4  = smSES - 4;  LABEL smSES4=  "smSES4: Secondary School Mean SES (0=4)"; RUN;


******************************************************************************
****** 						EXAMPLE 8 MODELS							******
******************************************************************************;

TITLE "SAS Model 1a: Empty Means, Random Intercept for Secondary School";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev =   / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=sschool TYPE=UN; *Level 2 for secondary school; 
RUN;

TITLE "SAS Model 1b: Add Random Intercept for Primary School (now crossed by Secondary)";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev =   / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

TITLE "SAS Model 2: Add Fixed Effects for School Denomination";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev = pdenom sdenom / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

TITLE "SAS Model 3a: Add Fixed Effect of Pupil SES";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev = pdenom sdenom pupSES4 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

TITLE "SAS Model 3b: Add Pupil SES Contextual Effects";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev = pdenom sdenom pupSES4 pmSES4 smSES4 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

TITLE "SAS Model 3c: Add Random Pupil SES Effect for Secondary School";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev = pdenom sdenom pupSES4 pmSES4 smSES4 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT pupSES4 / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT         / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

TITLE "SAS Model 3d: Add Random Pupil SES Effect for Primary School";
PROC MIXED DATA=work.example8 COVTEST NOCLPRINT NOITPRINT MAXIT=2000 NAMELEN=100 METHOD=REML;
	CLASS pschool sschool;
	MODEL achiev = pdenom sdenom pupSES4 pmSES4 smSES4 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT pupSES4 / SUBJECT=sschool TYPE=UN; *Level 2 for secondary; 
	RANDOM INTERCEPT pupSES4 / SUBJECT=pschool TYPE=UN; *Level 2 for primary; 
 RUN;

