* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "F:\12_ICPSR\ICPSR_2012_Download\SPSS".

* Open SPSS stacked version of example data.
GET FILE = "example/Example1_Stacked.sav".
DATASET NAME Stacked WINDOW=FRONT.

* SPSS code for mean-centering predictors for analysis.
DATASET ACTIVATE Stacked WINDOW=FRONT.
COMPUTE ageM = age - 10.5.
COMPUTE treatM = treat - .5.
COMPUTE ageXtreat = ageM * treatM. 
VARIABLE LABELS 	ageM "Age (0=10.5 mean)"
			              treatM "Treatment Group (0=.5 mean)"
			              ageXtreat "Age by Treatment Interaction (0=means)".
EXECUTE.

* SPSS example of Between-Person model via General Linear Model.
DATASET ACTIVATE Stacked WINDOW=FRONT.
UNIANOVA y BY ageM treatM
  	/EMMEANS = TABLES(ageM*treatM)
  	/DESIGN = ageM treatM ageM*treatM.

* SPSS example of Between-Person model via Regression.
DATASET ACTIVATE Stacked WINDOW=FRONT.
REGRESSION
  	/DEPENDENT y
  	/METHOD=ENTER ageM treatM ageXtreat.

* SPSS example of Between-Person model via Mixed.
DATASET ACTIVATE Stacked WINDOW=FRONT.
MIXED y WITH ageM treatM
	/METHOD = REML
	/PRINT  = SOLUTION
	/FIXED  = ageM treatM ageM*treatM.

*************************************************************.
* Open SPSS multivariate version of example data.
GET FILE = "example/Example1_Multiv.sav".
DATASET NAME Multiv WINDOW=FRONT.

* Mean-centering predictor for analysis.
DATASET ACTIVATE Multiv WINDOW=FRONT.
COMPUTE treatM = treat - .5.
VARIABLE LABELS treatM "Treatment Group (0=.5 mean)".
EXECUTE.

* SPSS example of Within-Person model via RM GLM.
DATASET ACTIVATE Multiv WINDOW=FRONT.
GLM y10 y11 BY treatM
  	/WSFACTOR = age 2 Polynomial
  	/EMMEANS = TABLES(treatM*age)
  	/WSDESIGN = age
  	/DESIGN = treatM.

* SPSS example of Within-Person model via Mixed.
DATASET ACTIVATE Stacked WINDOW=FRONT.
MIXED y WITH ageM treatM
	/METHOD = REML
	/PRINT  = SOLUTION
	/FIXED  = ageM treatM ageM*treatM
	/RANDOM = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN).


******************************************************************************
******		  BONUS SYNTAX: USING RESTRUCTURE WIZARD   		 				              ******
******	   GO BACK AND FORTH FROM MULTIVARIATE TO STACKED	               ******
******************************************************************************.

* Go from multivariate (wide) to stacked (long) for these data.
	*** Windows: DATA --> RESTRUCTURE --> 
	     Select 'Restructure selected variables into cases', NEXT
	     Select 'one' NEXT 
	     Keep 'Use case number', change name=id to name=PersonID
           Rename trans1 into y, send y10-y11 over into 'variables to be transposed' 
	   	     One index variable, NEXT
                 Keep defaults, but rename index to Wave, add label, NEXT
                 Select 'Keep and treat as fixed variables' NEXT
	     Select PASTE.
	**** Syntax to restructure.
		VARSTOCASES
			/MAKE y FROM y10 y11
			/INDEX Wave (2)
			/KEEP = ALL
			/NULL = KEEP.

* Need to recode wave to correct ages.
	RECODE wave (1=10) (2=11) INTO age.
	EXECUTE.

* How created unique case identifer for Between-Person models.
	SORT CASES BY PersonID age.
	COMPUTE CaseID = $CASENUM.
	EXECUTE.

* Go from stacked (long) to multivariate (wide) for these data.
	*** Windows: DATA --> RESTRUCTURE --> 
	     Select 'Restructure selected cases into variables', NEXT
	     Select 'one' NEXT 
	     Keep 'Use case number', change name=id to name=PersonID
           Rename trans1 into y, send y10-y11 over into 'variables to be transposed' 
	   	     One index variable, NEXT
                 Keep defaults, but rename index to Wave, add label, NEXT
                 Select 'Keep and treat as fixed variables' NEXT
	     Select PASTE.

* Go from stacked (long) to multivariate (wide) for these data.
	*** Windows: DATA --> RESTRUCTURE --> 
	     Select 'Restructure selected cases into variables', NEXT
	     Send 'PersonID' over into 'identifier variable' box
	     Send 'age' over into 'index variable' box NEXT
	     Allow it to sort data, NEXT
	     Group by original variables, NEXT 
	     Select PASTE.

	**** Syntax to restructure.
		SORT CASES BY PersonID age .
		CASESTOVARS
 			/ID = PersonID
 			/INDEX = age
 			/GROUPBY = VARIABLE .
	** As you can see, it not so helpfully makes new variables for everything,
	   time-varying or not. You can just keep one of those and delete the others.

**** END ****.



