
 ******************************************************************************
 ****** 						EXAMPLE 3 MODELS						 ******
 ******************************************************************************

 * STATA code to center time for polynomial models (and make quadratic versions)
gen c1sess = session - 1
gen c6sess = session  6
gen c1sess2 = c1sess * c1sess
gen c6sess2 = c6sess * c6sess
label variable c1sess  "c1sess: Session Centered at 1"
label variable c6sess  "c6sess: Session Centered at 6"
label variable c1sess2 "c1sess2: Quadratic Session Centered at 1"
label variable c6sess2 "c6sess2: Quadratic Session Centered at 6"	
	
 * STATA Model 1a: Empty Means, Random Intercept
xtmixed nm3rt ,  || id:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(session)), 
	estat ic, n(101)
	estat recovariance, level(id)

 * STATA Model 1b: Saturated Means, Unstructured Variance
xtmixed nm3rt ib(last).session, || id: , noconstant /// 
	variance reml residuals(unstructured, t(session)),
	estat ic, n(101),
	margins i.session

 * STATA Model 2a: Fixed Linear Time, Random Intercept
xtmixed nm3rt c.c1sess,  || id:  ,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store FixLin

 * STATA Model 2b: Random Linear Time
xtmixed nm3rt c.c1sess,  || id: c1sess,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandLin,
	lrtest RandLin FixLin

 * STATA Model 3a: Fixed Quadratic, Random Linear Time
xtmixed nm3rt c.c1sess c.c1sess2,  || id: c1sess,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store FixQuad

 * STATA Model 3b: Random Quadratic Time
xtmixed nm3rt c.c1sess c.c1sess2,  || id: c1sess c1sess2,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandQuad,
	lrtest RandQuad FixQuad,
	lincom 1*_cons + 0*c1sess   + 0*c1sess2     // intercept at session 1
	lincom 1*_cons + 1*c1sess   + 1*c1sess2     // intercept at session 2
	lincom 1*_cons + 2*c1sess   + 4*c1sess2     // intercept at session 3
	lincom 1*_cons + 2.5*c1sess + 6.25*c1sess2  // intercept at mean session
	lincom 1*_cons + 3*c1sess   + 9*c1sess2		// intercept at session 4
	lincom 1*_cons + 4*c1sess   + 16*c1sess2	// intercept at session 5
	lincom 1*_cons + 5*c1sess   + 25*c1sess2	// intercept at session 6
	lincom 1*c1sess + 0*c1sess2     // linear slope at session 1
	lincom 1*c1sess + 2*c1sess2     // linear slope at session 2
	lincom 1*c1sess + 4*c1sess2     // linear slope at session 3
	lincom 1*c1sess + 5*c1sess2     // linear slope at mean session
	lincom 1*c1sess + 6*c1sess2     // linear slope at session 4
	lincom 1*c1sess + 8*c1sess2     // linear slope at session 5
	lincom 1*c1sess + 10*c1sess2    // linear slope at session 6
	
 **************************************************************************
 
 * STATA Model 3a: Fixed Quadratic, Random Linear Time (Session 6=0)
xtmixed nm3rt c.c6sess c.c6sess2,  || id: c1sess,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store FixQuad

 * STATA Model 3b: Random Quadratic Time (Session 6=0)
xtmixed nm3rt c.c6sess c.c6sess2,  || id: c6sess c6sess2,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandQuad,
	lrtest RandQuad FixQuad
	
 
 
 ******************************************************************************
 ****** 						EXAMPLE 5 MODELS						 ******
 ******************************************************************************
 
 * centering level-2 predictor variables for analysis
gen age80 = age - 80
gen reas22 = absreas - 22
label variable age80 "age80: Age Centered (0=80 years)"
label variable reas22 "reas22: Abstract Reasoning Centered (0=22)"
* make education a grouping variable for purpose of demonstration only
gen educgrp=.   
replace educgrp=1 if (educyrs <= 12) 
replace educgrp=2 if (educyrs > 12 & educyrs <= 16)
replace educgrp=3 if (educyrs > 16)
label variable educgrp "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)"
 * interaction variables needed for lincom statements
gen age80c1sess   = age80 * c1sess
gen age80c1sess2  = age80 * c1sess2
gen reas22c1sess  = reas22 * c1sess
gen reas22c1sess2 = reas22 * c1sess2
 * create new variable to hold number of missing cases
 * then drop cases with incomplete predictors
egen nummiss = rowmiss(age80 reas22 educgrp)
drop if nummiss>0

 * STATA Model 3b: Random Quadratic Time Baseline in ML
xtmixed nm3rt c.c1sess c.c1sess2,  || id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Baseline,
	predict predtime
corr nm3rt predtime

 * STATA Model 4a: Age as Predictor of Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess2 c.age80 c.age80c1sess c.age80c1sess2,  ///
	|| id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Age,
	lrtest Age Baseline,
	predict predage
corr nm3rt predage

 * STATA Model 5a: +Reasoning as Predictor of Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess2 c.age80 c.age80c1sess c.age80c1sess2 ///
	c.reas22 c.reas22c1sess c.reas22c1sess2, || id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Reas,
	lrtest Reas Age,
	predict predreas
corr nm3rt predreas

* STATA Model 5b: +Reasoning as Predictor of Intercept, Linear Time Slope Only 
xtmixed nm3rt c.c1sess c.c1sess2 c.age80 c.age80c1sess c.age80c1sess2  ///
	c.reas22 c.reas22c1sess, || id: c1sess c1sess2, /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Reas2,
	lrtest Reas2 Age,
	lincom 1*reas22 + 0*reas22c1sess   // reasoning effect at session 1
	lincom 1*reas22 + 1*reas22c1sess   // reasoning effect at session 2
	lincom 1*reas22 + 2*reas22c1sess   // reasoning effect at session 3
	lincom 1*reas22 + 3*reas22c1sess   // reasoning effect at session 4
	lincom 1*reas22 + 4*reas22c1sess   // reasoning effect at session 5
	lincom 1*reas22 + 5*reas22c1sess   // reasoning effect at session 6
	predict predreas2
corr nm3rt predreas2

* STATA Model 6a: +Education Group on Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess2 c.age80 c.age80c1sess c.age80c1sess2  ///
	c.reas22 c.reas22c1sess ib(last).educgrp ib(last).educgrp#c.c1sess ///
	ib(last).educgrp#c.c1sess2, || id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Educ,
	lrtest Educ Reas2,
 * Estimating group means at first and last sessions
 	margins ib(last).educgrp,  at(c.c1sess=(0) c.c1sess2=(0))
 	margins ib(last).educgrp,  at(c.c1sess=(5) c.c1sess2=(25))
 * Contrasts between groups on intercept, linear, and quadratic slopes
 	test 1.educgrp=3.educgrp				// Low vs. High: Intercept
	test 2.educgrp=3.educgrp				// Med vs. High: Intercept
	test 1.educgrp=2.educgrp				// Low vs. Med:  Intercept
	test 1.educgrp#c1sess= 3.educgrp#c1sess		// Low vs. High: Linear
	test 2.educgrp#c1sess= 3.educgrp#c1sess		// Med vs. High: Linear
	test 1.educgrp#c1sess= 2.educgrp#c1sess		// Low vs. Med:  Linear
	test 1.educgrp#c1sess2=3.educgrp#c1sess2	// Low vs. High: Quad
	test 2.educgrp#c1sess2=3.educgrp#c1sess2	// Med vs. High: Quad
	test 1.educgrp#c1sess2=2.educgrp#c1sess2	// Low vs. Med:  Quad
	predict prededuc
corr nm3rt prededuc



