
 ******************************************************************************
 ****** 						EXAMPLE 6 MODELS						 ******
 ******************************************************************************

 * STATA code to center predictors
 * level-2 effect of negative mood
gen PMnm0 = PMnegmood - 0
label variable PMnm0 "PMnm0: Person Mean Negative Mood (0=0)"
 * level-1 effect to use with PERSON-MEAN-CENTERING
gen WPnm = negmood - PMnegmood
label variable WPnm "WPnm: Within-Person Negative Mood (0=PM)"
 * level-1 effect to use with GRAND-MEAN-CENTERING
gen TVnm0 = negmood - 0
label variable TVnm0 "TVnm0: Time-Varying Negative Mood (0=0)"
* interaction terms needed for lincom statements
gen WPnmsexmf  = WPnm  * sexmf
gen PMnm0sexmf = PMnm0 * sexmf
gen TVnm0sexmf = TVnm0 * sexmf



* STATA Model 1a: Empty Model for Daily Glucose Outcome
xtmixed lglucAM  , || id: ,  	/// 
	variance ml covariance(un) residuals(independent,t(day))

* STATA Model 1b: Empty Model for Daily Negative Mood Predictors
xtmixed negmood  , || id: ,  	/// 
	variance ml covariance(un) residuals(independent,t(day))

* STATA Model 2a: Fixed Effects of Negative Mood using PMC
xtmixed lglucAM c.WPnm c.PMnm0, || id: , 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	predict predmood,
	estimates store FixWP,
	lincom 1*WPnm 				// within-person mood effect
	lincom 1*PMnm0				// between-person mood effect
	lincom 1*PMnm0 - 1*WPnm 	// contextual mood effect
corr lglucAM predmood
	
* STATA Model 2b: Random Effect of WP Negative Mood using PMC
xtmixed lglucAM c.WPnm c.PMnm0, || id: WPnm, 	/// 
	variance ml covariance(un)  residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store RandWP,
	lrtest RandWP FixWP,
	lincom 1*WPnm 				// within-person mood effect
	lincom 1*PMnm0				// between-person mood effect
	lincom 1*PMnm0 - 1*WPnm 	// contextual mood effect
	
* STATA Model 2c: SPSS Model 2c: Fixed Effects of Sex (0=M, 1=F) by PMC Negative Mood 
xtmixed lglucAM c.WPnm c.PMnm0 c.sexmf c.WPnmsexmf c.PMnm0sexmf, /// 
	|| id: ,  variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	predict predsex,
	lincom 1*_cons + 0*sexmf				// intercept: men (mood=0)
	lincom 1*_cons + 1*sexmf				// intercept: women (mood=0)
	lincom 1*sexmf							// intercept: women diff (mood=0)
	lincom 1*WPnm + 0*WPnmsexmf				// within-person mood effect: men
	lincom 1*WPnm + 1*WPnmsexmf				// within-person mood effect: women
	lincom 1*WPnmsexmf						// within-person mood effect: women diff
	lincom 1*PMnm0 + 0*PMnm0sexmf			// between-person mood effect: men
	lincom 1*PMnm0 + 1*PMnm0sexmf			// between-person mood effect: women
	lincom 1*PMnm0sexmf						// between-person mood effect: women diff
	lincom 1*PMnm0 + 0*PMnm0sexmf - 1*WPnm + 0*WPnmsexmf 	// contextual mood effect: men
	lincom 1*PMnm0 + 1*PMnm0sexmf - 1*WPnm - 1*WPnmsexmf	// contextual mood effect: women
	lincom 1*PMnm0sexmf -1*WPnm sexmf			     		// contextual mood effect: women diff 
corr lglucAM predsex
	
* STATA Model 3: Fixed Effect of TV Negative Mood only using GMC
xtmixed lglucAM c.TVnm0, || id: , variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207)
	
* STATA Model 3a: Fixed Effects of Negative Mood using GMC
xtmixed lglucAM c.TVnm0 c.PMnm0, || id: , 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store FixTV,
	lincom 1*TVnm0 				// within-person mood effect
	lincom 1*TVnm0 + 1*PMnm0	// between-person mood effect
	lincom 1*PMnm0				// contextual mood effect

* STATA Model 3b: Random Effect of WP Negative Mood using GMC
xtmixed lglucAM c.TVnm0 c.PMnm0, || id: TVnm0, 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store RandTV,
	lrtest RandTV FixTV,
	lincom 1*TVnm0 				// within-person mood effect
	lincom 1*TVnm0 + 1*PMnm0	// between-person mood effect
	lincom 1*PMnm0				// contextual mood effect
	
* STATA Model 3c: SPSS Model 2c: Fixed Effects of Sex (0=M, 1=F) by GMC Negative Mood 
xtmixed lglucAM c.TVnm0 c.PMnm0 c.sexmf c.TVnm0sexmf c.PMnm0sexmf, /// 
	|| id: ,  variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	lincom 1*_cons + 0*sexmf					  	// intercept: men (mood=0)
	lincom 1*_cons + 1*sexmf					  	// intercept: women (mood=0)
	lincom 1*sexmf					  	  			// intercept: women diff (mood=0)
	lincom 1*TVnm0 + 0*TVnm0sexmf			  	  	// within-person mood effect: men
	lincom 1*TVnm0 + 1*TVnm0sexmf				  	// within-person mood effect: women
	lincom 1*TVnm0sexmf						  		// within-person mood effect: women diff
	lincom 1*TVnm0 + 0*TVnm0sexmf + 1*PMnm0 + 0*PMnm0sexmf 	// between-person mood effect: men
	lincom 1*TVnm0 + 1*TVnm0sexmf + 1*PMnm0 + 1*PMnm0sexmf 	// between-person mood effect: women
	lincom 1*TVnm0sexmf + 1*PMnm0sexmf			  			// between-person mood effect: women diff
	lincom 1*PMnm0 + 0*PMnm0sexmf				  	// contextual mood effect: men
	lincom 1*PMnm0 + 1*PMnm0sexmf				  	// contextual mood effect: women
	lincom 1*PMnm0sexmf						  		// contextual mood effect: women diff




